@@ -1,9 +1,6 @@
 # -*- coding:utf-8 -*-
 
-# First Created: 2011-07-03 19:29:48 +0900
-# Last Modified: 2011-07-05 21:34:18 +0900
-
-# Copyright (c) 2011 Naoya INADA <naoina@naniyueni.org>
+# Copyright (c) 2011 Naoya INADA <naoina@kuune.org>
 # All rights reserved.
 
 # Redistribution and use in source and binary forms, with or without
@@ -27,16 +24,7 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 
-__author__ = "Naoya INADA <naoina@naniyueni.org>"
-
-__all__ = [
-        ]
+__author__ = "Naoya INADA <naoina@kuune.org>"
 
 from .directives.autolink import *
-
-
-def main():
-    pass
-
-if __name__ == "__main__":
-    main()
+from .roles import *
