@@ -29,7 +29,7 @@ class HatenaTranslator(BaseTranslator):
         BaseTranslator.__init__(self, document)
 
         self.section_level = 0
-        self.initial_header_level = 1  #TODO: int(settings.initial_header_level)
+        self.initial_header_level = 1  # TODO: int(settings.initial_header_level)
         self.line_block_level = 0
         self.list_level = 0
         self.is_enum = True
@@ -505,6 +505,17 @@ class HatenaTranslator(BaseTranslator):
         if not self.in_paragraph:
             self.body.append('\n')
 
+    def visit_code_block(self, node):
+        typ = node['type']
+        self.body.append('>|%s|' % typ)
+        self.body.append('\n')
+
+    def depart_code_block(self, node):
+        self.body.append('\n')
+        self.body.append('||<')
+        self.body.append('\n')
+        self.body.append('\n')
+
     # ==================
     #  Hatena directives
     # ==================
