@@ -5,6 +5,7 @@ from docutils.core import publish_file, publish_string
 
 from rst2hatena.hatena_writer import Writer
 
+
 class WriterTest(unittest.TestCase):
     """
     """
@@ -999,6 +1000,27 @@ Hatena "twitter" notation.
 [twitter:88453766201880576:detail]
 [twitter:88453766201880576:tree]
 [twitter:@naoina]
+"""
+        output = publish_string(str, writer=self.writer)
+        self.assertEqual(exp_str, output)
+
+
+    def test_twitter_roles(self):
+        str = """\
+roles for Hatena "twitter" notation.
+
+:twitter:`naoina`
+:twitter:`@naoina`
+
+before text :twitter:`@naoina` after text
+"""
+        exp_str = """\
+roles for Hatena "twitter" notation.
+
+[twitter:@naoina] [twitter:@naoina]
+
+before text [twitter:@naoina] after text
+
 """
         output = publish_string(str, writer=self.writer)
         self.assertEqual(exp_str, output)
@@ -1036,6 +1058,46 @@ map:x139.6983y35.6514
 map:x139.6983y35.6514:map
 map:x139.6983y35.6514:satellite:h300
 map:x139.6983y35.6514:hybrid:w300
+"""
+        output = publish_string(str, writer=self.writer)
+        self.assertEqual(exp_str, output)
+
+
+    def test_code_blocks(self):
+        str = """\
+.. code-block:: python
+
+   def main():
+       for i in range(1, 101):
+           if i % 15 == 0:
+              print "FizzBuzz"
+           elif i % 5 == 0:
+              print "Buzz"
+           elif i % 3 == 0:
+              print "Fizz"
+           else:
+              print i
+
+   if __name__ == '__main__':
+       main()
+"""
+        exp_str = """\
+>|python|
+def main():
+    for i in range(1, 101):
+        if i % 15 == 0:
+           print "FizzBuzz"
+        elif i % 5 == 0:
+           print "Buzz"
+        elif i % 3 == 0:
+           print "Fizz"
+        else:
+           print i
+
+if __name__ == '__main__':
+    main()
+||<
+
 """
         output = publish_string(str, writer=self.writer)
         self.assertEqual(exp_str, output)
